import random
import string

SLASH = "/"
HTTP = "http"
HTTPS = "https"


def random_string(prefix="", length=8):
    """
    Create a random string with specified 'length'. The string will
    contain ascii letters and digits.
    """
    return prefix + "".join(
        random.choice(string.ascii_letters + string.digits) for n in range(length)
    )


def get_id_from_url(url: str) -> int:
    """
    Get the object id from a url corresponding to a resource instance
    """
    try:
        if not url.endswith(SLASH):
            url += SLASH
        obj_id = url.rstrip("/").rsplit("/", 1)[-1]
        return int(obj_id)
    except Exception:
        raise ValueError(f"Invalid url: {url}")


def convert_http_to_https(url: str) -> str:
    """
    Convert http url to https url
    """
    if isinstance(url, str) and url.startswith(HTTP):
        if url.startswith(HTTPS):
            return url
        return url.replace(HTTP, HTTPS, 1)
    raise ValueError(f"Invalid url: {url}")


def join_url(url_head: str, url_tail: str) -> str:
    """
    Remove extra slash or add missing slash in joining two url parts
    """
    if not url_tail.endswith(SLASH):
        url_tail += SLASH
    url = None
    if (url_head.endswith(SLASH) and not url_tail.startswith(SLASH)) or (
        not url_head.endswith(SLASH) and url_tail.startswith(SLASH)
    ):
        url = url_head + url_tail
    elif url_head.endswith(SLASH) and url_tail.startswith(SLASH):
        url = url_head + url_tail[1:]
    else:
        url = url_head + SLASH + url_tail
    return url
